@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Gufw 12.04.1 - http://gufw.tuxfamily.org
+# Gufw 12.10.0 - http://gufw.tuxfamily.org
 # Copyright (C) 2008-2011 Marcos Alvarez Costales https://launchpad.net/~costales
 #
 # Gufw is free software; you can redistribute it and/or modify
@@ -60,7 +60,6 @@ class GuiGufw:
         self._set_ui_add(builder)
         self._set_ui_preferences(builder)
         self._set_ui_log(builder)
-        self._set_ui_switch()
         self.win_main.show()
     
     def _set_ui_main(self, builder):
@@ -77,6 +76,8 @@ class GuiGufw:
             self.win_main.resize(width, height)
         # Icon
         self.win_main.set_default_icon_from_file("/usr/share/icons/hicolor/48x48/apps/gufw.png")
+        # Switch ON/OFF
+        self.switchFirewall = builder.get_object("switchStatus")
         # Panel
         self.panelmain = builder.get_object("panelListeningRules")
         self.panelmain.set_position(self.fw.get_vpanel_pos())
@@ -237,14 +238,6 @@ class GuiGufw:
         self.log_txt_buffer = self.log_txt.get_buffer()
         self.log_btn_close  = builder.get_object("btnCloseLog")
         self.server_script  = builder.get_object("cbServerScript")
-        
-    def _set_ui_switch(self):
-        """Add toggle switch manually since Glade 3.10 doesn't support it yet"""
-        # Future TODO: Remove this rutine
-        self.switchFirewall = Gtk.Switch()
-        self.block_status.attach(self.switchFirewall, 1, 0, 1, 1)
-        self.switchFirewall.set_sensitive(False)
-        self.switchFirewall.show()
     
     def _set_main_values(self, statusbar_msg):
         """Set initial status for GUI"""
@@ -532,17 +525,18 @@ class GuiGufw:
         if self.type_preconf.get_active() == 1:
             SERVICES = { 0 : "ftp",
                          1 : "http",
-                         2 : "imap",
-                         3 : "nfs",
-                         4 : "pop3",
-                         #Samba
-                         5 : "135,139,445tcp|137,138udp",
-                         6 : "smtp",
-                         7 : "ssh",
+                         2 : "https",
+                         3 : "imap",
+                         4 : "nfs",
+                         5 : "pop3",
+                         #Samba > Changes number? > Changes hack below
+                         6 : "135,139,445tcp|137,138udp",
+                         7 : "smtp",
+                         8 : "ssh",
                          #VNC
-                         8 : "5900tcp",
+                         9 : "5900tcp",
                          #CUPS
-                         9 : "631" }
+                         10: "631" }
             service_txt = SERVICES[self.service_preconf.get_active()]
             all_ports = service_txt.split("|")
             for port_proto in all_ports:
@@ -562,8 +556,10 @@ class GuiGufw:
                     port     = port_proto
                     protocol = ""
                     is_program = False
-                    
+                
                 self.fw.add_rule(is_program, insert_number, action, direction, log, protocol, "", "", "", port)
+                if self.service_preconf.get_active() == 6: #Samba > Special command. Bug #72444
+                    self.fw.add_rule(is_program, insert_number, action, "", log, protocol, "any", port, "", "")
             
             if number_rules != self.fw.get_number_rules():
                 self._set_main_values(_("Rule added"))
@@ -585,7 +581,9 @@ class GuiGufw:
                          #Skype
                          5 : "443tcp",
                          #Transmission
-                         6 : "51413tcp#51413udp"}
+                         6 : "51413tcp#51413udp",
+                         #Ubuntu One
+                         7 : "443tcp#443udp" }
             port_proto = PROGRAMS[self.program_preconf.get_active()]
             ports_protos = port_proto.split("#")
             for prog in ports_protos:
@@ -599,7 +597,6 @@ class GuiGufw:
                     port     = prog.replace("both", "")
                     protocol = "both"
                     
-                # TODO Add rule program
                 self.fw.add_rule(True, insert_number, action, direction, log, protocol, "", "", "", port)
                     
             if number_rules != self.fw.get_number_rules(): 
@@ -806,7 +803,7 @@ class GuiGufw:
             self._set_initial_objects_preferences()
             self._set_main_values("")
             self.ui_builder.connect_signals(self)
-            # Glade hasn't a GTKSwitch yet. Future TODO: Remove this line
+            # Glade event button_press_event not works with keyboard. Future TODO: Remove this line
             self.switchFirewall.connect("notify::active", self.on_switchFirewall_toggled)
             self._refresh_report()
         else:
@@ -1033,7 +1030,7 @@ class GuiGufw:
         about = Gtk.AboutDialog()
         about.set_copyright(_("© 2008-2012 The Gufw Project\nShield logo © 2007 Michael Spiegel"))
         about.set_comments(_("Graphical user interface for ufw"))
-        about.set_version("12.04.1")
+        about.set_version("12.10.0")
         about.set_website("http://gufw.tuxfamily.org/")
         about.set_authors([_('''Lead developer:
 Marcos Alvarez Costales https://launchpad.net/~costales
